GMMVI: Gaussian Mixture Model Variational Inference
===================================================

The documentation is provided as `html <docs/build/html/index.html>`_ or `pdf <docs/build/latex/gmmvi.pdf>`_.
